Random Forest / Hough Voting Detection Algorithm
================================================

Unix / Mac compatible distribution based on the Random Forest code developed by Gall et. al.

The code has been parallelized in specific spots using OpenMP to help speed up training
and detection.  A Python wrapper has also been created to help with ease of testing.

REQUIRED:

https://github.com/bluemellophone/detecttools

https://github.com/bluemellophone/IBEIS2014
